@@ -99,7 +99,7 @@
  *
  * \section pagePdfGlobal Pdf global settings
  * The \ref wkhtmltopdf_global_settings structure contains the following settings:
- * - \b size.paperSize  The paper size of the output document, e.g. "A4".
+ * - \b size.pageSize  The paper size of the output document, e.g. "A4".
  * - \b size.width The with of the output document, e.g.  "4cm".
  * - \b size.height The height of the output document, e.g. "12in".
  * - \b orientation The orientation of the output document, must be either "Landscape" or "Portrait".
@@ -209,11 +209,11 @@ QApplication * a = 0;
 int usage = 0;
 
 void MyPdfConverter::warning(const QString & message) {
-	if (warning_cb) (warning_cb)(reinterpret_cast<wkhtmltopdf_converter*>(this), message.toUtf8().constData());
+	if (warning_cb && globalSettings->logLevel > settings::Error) (warning_cb)(reinterpret_cast<wkhtmltopdf_converter*>(this), message.toUtf8().constData());
 }
 
 void MyPdfConverter::error(const QString & message) {
-	if (error_cb) (error_cb)(reinterpret_cast<wkhtmltopdf_converter*>(this), message.toUtf8().constData());
+	if (error_cb && globalSettings->logLevel > settings::None) (error_cb)(reinterpret_cast<wkhtmltopdf_converter*>(this), message.toUtf8().constData());
 }
 
 void MyPdfConverter::phaseChanged() {
@@ -292,6 +292,10 @@ CAPI(int) wkhtmltopdf_init(int use_graphics) {
 		char * arg[] = {x, 0};
 		int aa = 1;
 
+#if QT_VERSION >= 0x050000 && defined(Q_OS_UNIX) && !defined(__EXTENSIVE_WKHTMLTOPDF_QT_HACK__)
+		setenv("QT_QPA_PLATFORM", "offscreen", 0);
+#endif
+
 		bool ug = true;
 #if defined(Q_OS_UNIX) || defined(Q_OS_MAC)
 #ifdef __EXTENSIVE_WKHTMLTOPDF_QT_HACK__
@@ -304,6 +308,7 @@ CAPI(int) wkhtmltopdf_init(int use_graphics) {
 		Q_UNUSED(use_graphics);
 #endif
 		a = new QApplication(aa, arg, ug);
+		a->setApplicationName(x);
 		MyLooksStyle * style = new MyLooksStyle();
 		a->setStyle(style);
 	}
@@ -468,21 +473,21 @@ CAPI(void) wkhtmltopdf_destroy_converter(wkhtmltopdf_converter * converter) {
 }
 
 /**
- * \brief Set the function that should be called when an errors occurs during conversion
+ * \brief Set the function that should be called when an warning message is issued during conversion
+ *
+ * \param converter The converter object on which warnings we want the callback to be called
+ * \param cb The function to call when warning message is issued
  *
- * \param converter The converter object on which errors we want the callback to be called
- * \param cb The function to call when an error occurs
  */
 CAPI(void) wkhtmltopdf_set_warning_callback(wkhtmltopdf_converter * converter, wkhtmltopdf_str_callback cb) {
 	reinterpret_cast<MyPdfConverter *>(converter)->warning_cb = cb;
 }
 
 /**
- * \brief Set the function that should be called when an warning message is issued during conversion
- *
- * \param converter The converter object on which warnings we want the callback to be called
- * \param cb The function to call when warning message is issued
+ * \brief Set the function that should be called when an errors occurs during conversion
  *
+ * \param converter The converter object on which errors we want the callback to be called
+ * \param cb The function to call when an error occurs
  */
 CAPI(void) wkhtmltopdf_set_error_callback(wkhtmltopdf_converter * converter, wkhtmltopdf_str_callback cb) {
 	reinterpret_cast<MyPdfConverter *>(converter)->error_cb = cb;
@@ -679,7 +684,7 @@ CAPI(long) wkhtmltopdf_get_output(wkhtmltopdf_converter * converter, const unsig
 //  LocalWords:  QString cb bool ok globalSettings phaseChanged progressChanged
 //  LocalWords:  objectSettings utf CropSettings HeaderFooter ImageGlobal dpi sa
 //  LocalWords:  PdfGlobal PdfObject TableOfContent pagePdfGlobal pagePdfObject
-//  LocalWords:  pageImageGlobal pageGlobalLoad paperSize colorMode Grayscale
+//  LocalWords:  pageImageGlobal pageGlobalLoad pageSize colorMode Grayscale
 //  LocalWords:  pageOffset outlineDepth dumpOutline stdout pageLoad pageWeb aa
 //  LocalWords:  includeInOutline pagesCount tocXsl xsl struct typedef str CAPI
 //  LocalWords:  param STRINGIZEE STRINGIZE deinit qApp strcpy wkhtmltox arg ug
